@@ -14,9 +14,9 @@ import scipy.io.wavfile as wf
 from pydub import AudioSegment
 
 #local imports 
-from utils.data_input import convert_wav
-from utils.standardizer import read_phn,TIMIT_to_IPA, IPA_to_TIMIT,file_text
-from utils.noise_sidefunc import load_params,segmental_snr_mixer
+from .data_input import convert_wav
+from .standardizer import read_phn,TIMIT_to_IPA, IPA_to_TIMIT,file_text
+from .noise_sidefunc import load_params,segmental_snr_mixer
 
 
 #Function to give a overview of the phoneme error rate 
